width = 0;
height = 0;
var GUI = function() {
  this.activeScreen = [];
  this.screensObjectsList = [];
  this.currentScreen = null;
};
GUI.prototype = {preload:function() {
  this.screenGame = new ScreenGame;
  this.screensObjectsList.push(this.screenGame);
  this.screenMenu = new ScreenMainMenu;
  this.screensObjectsList.push(this.screenMenu);
  this.pulseLocks = {};
  this.createWrongOrientation();
}, componentToHex:function(c) {
  var hex = c.toString(16);
  return hex.length == 1 ? "0" + hex : hex;
}, hexToRgb:function(hex) {
  var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
  return result ? {r:parseInt(result[1], 16), g:parseInt(result[2], 16), b:parseInt(result[3], 16)} : null;
}, rgbToHex:function(color) {
  return "0x" + this.componentToHex(color.r) + this.componentToHex(color.g) + this.componentToHex(color.b);
}, create:function() {
  this.buttonCreator = new Buttons;
  this.buttonCreator.create();
}, createBitmaps:function() {
}, addInputOverHighlight:function(image, scale) {
  const currScaleX = image.scale.x;
  const currScaleY = image.scale.y;
  var tween;
  image.onInputOver.add(function() {
    tween = game.add.tween(image.scale);
    tween.to({x:image.scale.x + scale, y:image.scale.y + scale}, 350, Phaser.Easing.Linear.None);
    tween.start();
  }, this);
  image.onInputOut.add(function() {
    tween.stop();
    image.scale.x = currScaleX;
    image.scale.y = currScaleY;
  }, this);
}, createBackground:function() {
  var sizes = {};
  if (isWideScreen()) {
    sizes.topRight = game.width * .2;
    sizes.bottomRight = game.width * .22;
    sizes.bottomLeft = game.width * .24;
    sizes.topLeft = game.width * .2;
    sizes.bgSize = game.width > game.height ? game.height : game.width;
  } else {
    sizes.bgSize = game.width;
    sizes.topRight = game.width * .35;
    sizes.bottomRight = game.width * .36;
    sizes.bottomLeft = game.width * .35;
    sizes.topLeft = game.width * .45;
  }
  this.loadingGroup = game.add.group();
  const backgroundSize = sizes.bgSize;
  var background = guiManager.createImage(game.width / 2, game.height / 2, game.width, game.height, "splashBG", this.preloadGroup);
  var topLeft = guiManager.createSprite(0, 0, sizes.topLeft, sizes.topLeft * .82, "pak_bg", "bg_upLeft", this.preloadGroup);
  var topRight = guiManager.createSprite(game.width - sizes.topRight, 0, sizes.topRight, sizes.topRight, "pak_bg", "bg_upRight", this.preloadGroup);
  var bottomLeft = guiManager.createSprite(0, game.height - sizes.bottomLeft, sizes.bottomLeft, sizes.bottomLeft, "pak_bg", "bg_bottomLeft", this.preloadGroup);
  var bottomRight = guiManager.createSprite(game.width - sizes.bottomRight, game.height - sizes.bottomRight, sizes.bottomRight, sizes.bottomRight, "pak_bg", "bg_bottomRight", this.preloadGroup);
  var gameLogo = guiManager.createSprite(game.width / 2, game.height / 2, backgroundSize, backgroundSize, "pak_bg", "bg_logo", this.preloadGroup);
  setObjectAnchor(topLeft, 0, 0);
  setObjectAnchor(topRight, 0, 0);
  setObjectAnchor(bottomRight, 0, 0);
  setObjectAnchor(bottomLeft, 0, 0);
}, update:function() {
}, getRandomColor:function() {
  return "0x" + Math.floor(Math.random() * 16777215).toString(16);
}, loadScreen:function(screen) {
  if (this.currentScreen != null) {
    this.currentScreen.hideScreen();
  }
  if (screen.loaded == null) {
    screen.create();
  }
  this.currentScreen = screen;
  screen.drawScreen();
}, createWrongOrientation:function() {
  this.orientationGroup = game.add.group();
  this.orientationGroup.visible = false;
  this.orientationBg = guiManager.createImage(game.width / 2, game.height / 2, game.width, game.height, "bgMenu", this.orientationGroup);
  this.img_rotate = guiManager.createImage(game.width / 2, game.height / 2, game.width, game.height, "rotate", this.orientationGroup);
}, loadLevel:function(category, level) {
  if (game.paused === true) {
    game.paused = false;
  }
  if (this.currentScreen != null) {
    this.currentScreen.hideScreen();
  }
  this.screenGame.preload();
  this.screenGame.levelIndex = level;
  this.screenGame.categoryIndex = category;
  this.screenGame.create();
  this.screenGame.drawScreen();
  this.currentScreen = this.screenGame;
}, createImage:function(posX, posY, width, height, imageName, parentGroup) {
  var image = game.add.image(posX, posY, imageName);
  image.width = width;
  image.height = height;
  setObjectAnchor(image, .5, .5);
  if (parentGroup != null) {
    parentGroup.addChild(image);
  }
  return image;
}, createImage2:function(posX, posY, imageName, parentGroup) {
  var image = game.add.image(posX, posY, imageName);
  setObjectAnchor(image, .5, .5);
  if (parentGroup != null) {
    parentGroup.addChild(image);
  }
  return image;
}, createSprite:function(posX, posY, width, height, spritesheetKey, imageName, parentGroup) {
  var image = game.add.sprite(posX, posY, spritesheetKey, imageName);
  image.width = width;
  image.height = height;
  setObjectAnchor(image, .5, .5);
  if (parentGroup != null) {
    parentGroup.addChild(image);
  }
  return image;
}, addPulsing:function(image, finalScale, duration, numberOfPulses) {
  if (numberOfPulses == undefined) {
    numberOfPulses = 1;
  }
  var imageId = image.key + (image.position.x + image.position.y);
  if (this.pulseLocks[imageId] != null) {
    return;
  }
  this.pulseLocks[imageId] = true;
  var pulses = 0;
  var firstPulse;
  var secondPulse;
  const finalWidth = image.width * finalScale;
  const finalHeight = image.height * finalScale;
  const initialWidth = image.width;
  const initialHeight = image.height;
  firstPulse = game.add.tween(image);
  firstPulse.to({width:finalWidth, height:finalHeight}, duration, Phaser.Easing.Linear.None, true).onComplete.add(function() {
    secondPulse = game.add.tween(image);
    secondPulse.to({width:initialWidth, height:initialHeight}, duration, Phaser.Easing.Linear.None, true);
    secondPulse.onComplete.add(function() {
      pulses++;
      if (pulses < numberOfPulses) {
        firstPulse.start();
      } else {
        delete this.pulseLocks[imageId];
      }
    }, this);
  }, this);
}};

